gmean: geometric mean

View source: R/supp.R

gmeanR Documentation

geometric mean

Description

geometric mean

Usage

gmean(x, na.rm = TRUE)

Arguments

x

vector

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

Details

Geometric mean of a vector. Indicates the central tendency or typical value of a set of numbers by using the product of their values (as opposed to the arithmetic mean which uses their sum). The geometric mean is defined as the nth root of the product of n numbers.


elisvb/CCAM documentation built on March 13, 2023, 6:55 a.m.