| simulate.ccam | R Documentation |
Simulate from a ccam object
## S3 method for class 'ccam' simulate(object, nsim = 1, seed = NULL, full.data = TRUE, ...)
object |
ccam fitted object (result from ccam.fit) |
nsim |
number of response lists to simulate. Defaults to 1. |
seed |
random number seed |
full.data |
logical, should each inner list contain a full list of data. Defaults to TRUE |
... |
extra arguments |
...
returns a list of lists. The outer list has length nsim. Each inner list contains simulated values of logF, logN, and obs with dimensions equal to those parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.