| defcon | R Documentation |
Setup basic minimal configuration for ccam assessment
defcon(dat)
dat |
ccam data object |
...
a list containing
minAge |
minimum age |
maxAge |
maximum age |
maxAgePlusGroup |
plus group (0 or 1) |
keySel |
selectivity structure |
keyLogFpar |
survey catchability |
keyQpow |
Qpow structure |
keyVarF |
F variance structure |
keyVarLogN |
N variance structure |
keyVarObs |
observation variance structure |
obsCorStruct |
correlation structure if MVN observation error |
keyCorObs |
correlation if MVN observation error |
stockRecruitmentModelCode |
0: RW, 1: ricker, 2: BH, 3: mean |
noScaledYears |
set to zero as a placeholder here. |
keyScaledYears |
a scalar set to zero as a placeholder here. |
keyParScaledYA |
an array set to zero as a placeholder here. |
fbarRange |
Range of ages over which Fbar should be taken |
obsLikelihoodFlag |
A vector with an element for each fleet. "LN","ALN" or for fleetType 3 "CE" or "RO" |
fixVarToWeight |
a scalar set to zero as a placeholder here. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.