| forecast | R Documentation |
forecast function to do shortterm
forecast(fit, fscale = NULL, catchval = NULL, fval = NULL, MP = NULL, nosim = 1000, year.base = max(fit$data$years), ave.years = max(fit$data$years) + (-4:0), rec.years = max(fit$data$years) + (-9:0), rec.meth = 4, rec.scale = 1, MPlabel = NULL, OMlabel = NULL, overwriteSelYears = NULL, deterministic = FALSE, CZ = 0, HZ = 0, IE = 0, capLower = NULL, capUpper = NULL, UL.years = max(fit$data$years) + (-4:0), TAC.base = 0, bio.scale = NULL, verbose = FALSE, deadzone = 0, Flim = 3, fleet = 3)
fit |
an assessment object of type ccam, as returned from the function ccam.fit |
fscale |
a vector of f-scales. See details. |
catchval |
a vector of target catches. See details. |
fval |
a vector of target f values. See details. |
MP |
a vector of management strategie names. see avail('MP') |
nosim |
number of simulations default is 1000 |
year.base |
starting year default last year in assessment. Currently it is only supported to use last assessment year or the year before |
ave.years |
vector of years to average for weights, maturity, M and such |
rec.years |
vector of years to use to resample recruitment from |
rec.meth |
methode to project recruitment. Autocorrelation can be specified as attribute ('AC'). |
rec.scale |
scale recruitment (default is 1) |
overwriteSelYears |
if a vector of years is specified, then the average selectivity of those years is used (not recommended) |
deterministic |
option to turn all process noise off (not recommended, as it will likely cause bias) |
CZ |
critical zone (to calculate probability ssb above) |
HZ |
Healty zone (to calculate probability ssb above) |
IE |
implementation error type. See avail('IE') |
capLower |
lower limit of TAC (before IE) |
capUpper |
upper limit of TAC (before IE) |
UL.years |
vector of years to use to resample upper/lower catch bound ranges from |
TAC.base |
TAC last year |
bio.scale |
names list with multipliers used to scale future bio values (nm, en, pr,sw,cw,lf,dw,lw,pm,pf) |
deadzone |
ssb value below which there is no recruitment anymore and the stock goes extinct. Avoids 'dead' stock popping back to live because of recruitment peak. |
Flim |
Upper limit of F value. defaults to 3. |
fleet |
fleet for which the future observations are extracted |
label |
optional label to appear in short table |
There are four ways to specify a scenario; fscale, catchval, fval and MP. There are also multiple recruitment options;
parametric BH estimated within the model. If attribute 'AC' not NULL, use autocorrelation estimated outside the model.
mean value of rec.pool with sd. If attribute 'AC' not NULL, use autocorrelation estimated outside the model.
sample value from rec.pool
sample value backwards (for first year one of the two last estimted values)
idem as 3 but sample RPS
idem as 4 but sample RPS
Set.seed is used with the number of simulations to facilitate comparison between different runs (using e.g. different catchvalues/MPs) for;
last year state
observation residuals
future data (M, proportion mature, weight-at-age, etc.)
an object of type ccamforecast
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.