| gmean | R Documentation |
geometric mean
gmean(x, na.rm = TRUE)
x |
vector |
na.rm |
a logical value indicating whether NA values should be stripped before the computation proceeds. |
Geometric mean of a vector. Indicates the central tendency or typical value of a set of numbers by using the product of their values (as opposed to the arithmetic mean which uses their sum). The geometric mean is defined as the nth root of the product of n numbers.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.